| Title: | R Bindings to the Feather 'API' |
|---|---|
| Description: | Read and write feather files, a lightweight binary columnar data store designed for maximum speed. |
| Authors: | Hadley Wickham [aut, cre], RStudio [cph], LevelDB Authors [ctb] |
| Maintainer: | Hadley Wickham <[email protected]> |
| License: | Apache License 2.0 |
| Version: | 0.4.0.9000 |
| Built: | 2026-05-07 08:13:36 UTC |
| Source: | https://github.com/wesm/feather |
These functions permit using a feather dataset much like a regular (read-only) data frame without reading everything into R.
feather(path) feather_metadata(path)feather(path) feather_metadata(path)
path |
Path to feather file |
They work by using arrow::read_feather() to read the data in as an Arrow
Table, an efficient data structure that supports many data-frame methods.
See the Arrow package documentation
for more information.
An arrow::Table
Read and write feather files.
read_feather(path, columns = NULL, ...) write_feather(x, path, version = 1, ...)read_feather(path, columns = NULL, ...) write_feather(x, path, version = 1, ...)
path |
Path to feather file |
columns |
Columns to read (names or indexes), or a
tidy selection specification
of columns, as used in |
... |
Additional arguments passed to the |
x |
A data frame to write to disk |
version |
integer in |
Both functions return a tibble/data frame. write_feather
invisibly returns x (so you can use this function in a pipeline).
mtcars2 <- read_feather(feather_example("mtcars.feather")) mtcars2mtcars2 <- read_feather(feather_example("mtcars.feather")) mtcars2